pytilities.infinity — Pytilities 1.2.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities 1.2.0 documentation »
- API documentation »
- pytilities »

# pytilities.infinity

Provides a cross-platform alternative to the platform dependent float(‘inf’).

`pytilities.infinity.` `infinity` = <pytilities.infinity._PositiveInfinity object at 0x2ada350>

`pytilities.infinity.` `negative_infinity` = <pytilities.infinity._NegativeInfinity object at 0x2df72d0>

`pytilities.infinity.` `nan` = <pytilities.infinity._NAN object at 0x2df74d0>

`pytilities.infinity.` `is_infinity`(number)

  Returns: | True if number is infinity or -infinity

`pytilities.infinity.` `is_nan`(number)

  Returns: | True if number is nan

`pytilities.infinity.` `is_negative_infinity`(number)

  Returns: | True if number is -infinity

`pytilities.infinity.` `is_positive_infinity`(number)

  Returns: | True if number is infinity

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities 1.2.0 documentation »
- API documentation »
- pytilities »